pub enum SpaceRef {
Resolved(SpaceId),
Deferred(Box<str>),
}Expand description
A space reference that may be unresolved at Phase 2 parse time.
Variants
Resolved(SpaceId)
A space of the compiled specification. Always this variant by the time a consumer sees an expression.
Deferred(Box<str>)
Space name absent from the symbol table during Phase 2; resolved in Phase 3.
Implementations