Varnode

Struct Varnode 

pub struct Varnode {
    pub space: SpaceId,
    pub offset: u64,
    pub size: usize,
}
A storage location or constant used as an input or output of a p-code op.

space and offset identify the location; size is its width in bytes. A constant is represented by SPACE_CONST and stores its value in offset.

Fields

space: SpaceId

Address space containing this varnode, or SPACE_CONST for a constant.

offset: u64

Byte offset in space, or the value for a constant-space varnode.

size: usize

Width in bytes.

Implementations

Source

impl Varnode

pub const fn new(space: SpaceId, offset: u64, size: usize) -> Self

Creates a varnode at offset in space with byte width size.

pub const fn constant(value: u64, size: usize) -> Self

Creates a constant-space varnode containing value with byte width size.

pub fn is_constant(self) -> bool

Returns whether this is a constant-space varnode.