Module space

Module space 

Memory spaces: uniformly-addressed regions that values live in.

Spaces model distinct address ranges — for example RAM, ROM, and the processor register file are each their own space. The basic unit for a space is a byte; this can be changed by setting the space’s word size (bytes per addressable unit) and address size (bytes needed to hold a pointer into the space).

Structs

Space
A named, uniformly-addressed memory region.
SpaceId
A stable, context-unique identifier for a Space.

Enums

SpaceType
The broad category of a memory space.

Constants

SPACE_CONST
The const space is used for constant values such as immediate values

Traits

SpaceStore
Anything that can resolve a SpaceId back to its Space.

Type Aliases

SpaceRef