pub fn lower_instruction_into<R>(
ast: &PcodeAst,
context: &impl PcodeLoweringContext,
sink: impl FnOnce(&[PcodeOp]) -> R,
) -> Result<R, PcodeLowerError>Expand description
Lowers ast and exposes its resolved flat p-code to sink without
materializing an InstructionPcode for the caller.
The lowerer still keeps operations temporarily while resolving local branch labels. Consumers which can process a complete instruction synchronously can therefore avoid making the flat p-code an owned boundary object.